package perftype
import "k8s.io/kubernetes/test/e2e_node/perftype"
Index ¶
Types ¶
type NodeTimeSeries ¶
type NodeTimeSeries struct {
OperationData map[string][]int64 `json:"op_series,omitempty"`
ResourceData map[string]*ResourceSeries `json:"resource_series,omitempty"`
Labels map[string]string `json:"labels"`
Version string `json:"version"`
}
NodeTimeSeries defines the time series of the operations and the resource usage.
type ResourceSeries ¶
type ResourceSeries struct {
Timestamp []int64 `json:"ts"`
CPUUsageInMilliCores []int64 `json:"cpu"`
MemoryRSSInMegaBytes []int64 `json:"memory"`
Units map[string]string `json:"unit"`
}
ResourceSeries defines the time series of the resource usage.
Source Files ¶
perftype.go
- Version
- v1.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Last checked
- 13 seconds ago –
Tools for package owners.